import React from 'react';
import styled from 'styled-components';

import defaultTheme from '../../theme';
import { Box } from '../../elements';

export interface InputProps {
  label?: React.ReactNode;
}

const StyledInput = styled.input<InputProps>(
  {
    margin: 0,
    outline: 0,
    textAlign: 'left',
    lineHeight: '1.5em',
    padding: '.5em 1em',
  },
  ({ theme }) => {
    return {
      borderRadius: theme.sizes.borderRadius,
      border: `1px solid ${theme.greyscale.medium}`,

      '&:focus, &:focus:hover, &:hover': {
        borderColor: theme.colors.primary.default,
      },

      '&:hover': {
        boxShadow: `1px 1px 12px 0 ${theme.greyscale.dark}`,
      },
    };
  },
);

StyledInput.defaultProps = {
  theme: defaultTheme,
};

export const Input: React.FC<InputProps> = (props) => {
  if (!props.label) {
    return <StyledInput {...props} />;
  }

  return (
    <Box type="row" verticalAlign="center">
      <Box size={[1, 0.25]}>
        <label>{props.label}</label>
      </Box>
      <Box size={[1, 0.75]}>
        <StyledInput {...props} />
      </Box>
    </Box>
  );
};
